<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="75"/>
        <location filename="../mainwindow.cpp" line="434"/>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>MX Cleanup</source>
        <translation>MX Cleanup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Clean フォルダー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>All (potentially dangerous)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Not accessed today (safer)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>Display help </source>
        <translation>ヘルプ表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="259"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <location filename="../mainwindow.cpp" line="549"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="335"/>
        <source>Empty Trash</source>
        <translation>ゴミ箱を空にする</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Trash older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <location filename="../mainwindow.ui" line="485"/>
        <location filename="../mainwindow.ui" line="691"/>
        <source>Don&apos;t empty</source>
        <translation>空にしないでください</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <location filename="../mainwindow.ui" line="723"/>
        <source> days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>All users</source>
        <translation>全てのユーザー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Selected user</source>
        <translation>選択したユーザー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>Clear APT Cache</source>
        <translation>APT のキャッシュをクリア</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Old files</source>
        <translation>以前のファイル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>All files</source>
        <translation>全てのファイル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="556"/>
        <source>At reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="606"/>
        <source>Free Disk Space for User</source>
        <translation>ユーザの用の空きディスク容量</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <location filename="../mainwindow.ui" line="631"/>
        <source>Select user to repair</source>
        <translation>復旧するユーザーの選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="634"/>
        <source>Select user:</source>
        <translation>ユーザーの選択:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>Kernel removal tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="771"/>
        <source>List and select kernels to remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>ディスク使用状況を分析するグラフィカルツール</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>ディスク使用状況アナライザの起動</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Schedule</source>
        <translation>スケジュール</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>No automatic clean</source>
        <translation>自動クリーニングなし</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Daily</source>
        <translation>毎日</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Weekly</source>
        <translation>毎週</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Monthly</source>
        <translation>毎月</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="650"/>
        <source>Delete Logs</source>
        <translation>ログ消去</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="675"/>
        <source>All logs</source>
        <translation>全てのログ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Old logs</source>
        <translation>以前のログ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <source>Logs older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Cleanup command done</source>
        <translation>Cleanup コマンド終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiBが解放されました</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>About</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>Quick and safe removal of old files</source>
        <translation>古いファイルの迅速かつ安全な削除</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <source>Remove selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>Similar kernels that can be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Other kernels that can be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">このプログラムは root で実行する必要があります。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Quick safe removal of old files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
